@@ -33,8 +33,14 @@
 # ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 
+from ._version import __version__, __version_tuple__  # noqa: F401
+
 # fmt: off
 from .spglib import (  # noqa: F401
+    MagneticSpaceGroupType,
+    SpaceGroupType,
+    SpglibDataset,
+    SpglibMagneticDataset,
     delaunay_reduce,
     find_primitive,
     get_BZ_grid_points_by_rotations,
@@ -43,7 +49,9 @@ from .spglib import (  # noqa: F401
     get_grid_points_by_rotations,
     get_hall_number_from_symmetry,
     get_ir_reciprocal_mesh,
+    get_layergroup,
     get_magnetic_spacegroup_type,
+    get_magnetic_spacegroup_type_from_symmetry,
     get_magnetic_symmetry,
     get_magnetic_symmetry_dataset,
     get_magnetic_symmetry_from_database,
@@ -59,9 +67,10 @@ from .spglib import (  # noqa: F401
     niggli_reduce,
     refine_cell,
     relocate_BZ_grid_address,
+    spg_get_commit,
+    spg_get_version,
+    spg_get_version_full,
     standardize_cell,
 )
 
 # fmt: on
-
-__version__ = "%d.%d.%d" % get_version()
