@@ -46,26 +46,26 @@
 
 static int get_num_attempts();
 
-static int delaunay_reduce(double red_lattice[3][3], const double lattice[3][3],
-                           const int aperiodic_axis, const double symprec);
-static int delaunay_reduce_basis(double basis[4][3], const int lattice_rank,
-                                 const double symprec);
+static int delaunay_reduce(double red_lattice[3][3], double const lattice[3][3],
+                           int const aperiodic_axis, double const symprec);
+static int delaunay_reduce_basis(double basis[4][3], int const lattice_rank,
+                                 double const symprec);
 static void get_delaunay_shortest_vectors(double basis[4][3],
-                                          const int lattice_rank,
-                                          const double symprec);
-static int get_extended_basis(double basis[4][3], const double lattice[3][3],
-                              const int aperiodic_axis);
-static int delaunay_reduce_basis_2D(double basis[3][3], const int lattice_rank,
-                                    const double symprec);
+                                          int const lattice_rank,
+                                          double const symprec);
+static int get_extended_basis(double basis[4][3], double const lattice[3][3],
+                              int const aperiodic_axis);
+static int delaunay_reduce_basis_2D(double basis[3][3], int const lattice_rank,
+                                    double const symprec);
 static void get_delaunay_shortest_vectors_2D(double basis[3][3],
-                                             const double unique_vec[3],
-                                             const int lattice_rank,
-                                             const double symprec);
+                                             double const unique_vec[3],
+                                             int const lattice_rank,
+                                             double const symprec);
 static void get_extended_basis_2D(double basis[3][3],
-                                  const double lattice[3][2]);
+                                  double const lattice[3][2]);
 
 int get_num_attempts() {
-    const char *num_attempts_str = getenv("SPGLIB_NUM_ATTEMPTS");
+    char const *num_attempts_str = getenv("SPGLIB_NUM_ATTEMPTS");
     if (num_attempts_str != NULL) {
         // Try to parse the string as an integer
         char *end;
@@ -74,7 +74,7 @@ int get_num_attempts() {
         if (end != num_attempts_str && num_attempts > 0 &&
             num_attempts < INT_MAX)
             return (int)num_attempts;
-        warning_print("Could not parse SPGLIB_NUM_ATTEMPTS=%s\n",
+        warning_print("spglib: Could not parse SPGLIB_NUM_ATTEMPTS=%s\n",
                       num_attempts_str);
     }
     // Otherwise return default number of attempts
@@ -82,8 +82,8 @@ int get_num_attempts() {
 }
 
 /* Return 0 if failed */
-int del_delaunay_reduce(double min_lattice[3][3], const double lattice[3][3],
-                        const double symprec) {
+int del_delaunay_reduce(double min_lattice[3][3], double const lattice[3][3],
+                        double const symprec) {
     debug_print("del_delaunay_reduce (tolerance = %f):\n", symprec);
 
     return delaunay_reduce(min_lattice, lattice, -1, symprec);
@@ -91,8 +91,8 @@ int del_delaunay_reduce(double min_lattice[3][3], const double lattice[3][3],
 
 /* Return 0 if failed */
 int del_layer_delaunay_reduce(double min_lattice[3][3],
-                              const double lattice[3][3],
-                              const int aperiodic_axis, const double symprec) {
+                              double const lattice[3][3],
+                              int const aperiodic_axis, double const symprec) {
     debug_print("del_layer_delaunay_reduce (tolerance = %f):\n", symprec);
 
     return delaunay_reduce(min_lattice, lattice, aperiodic_axis, symprec);
@@ -101,8 +101,8 @@ int del_layer_delaunay_reduce(double min_lattice[3][3],
 /* Delaunay reduction */
 /* Reference can be found in International table A. */
 /* Return 0 if failed */
-static int delaunay_reduce(double red_lattice[3][3], const double lattice[3][3],
-                           const int aperiodic_axis, const double symprec) {
+static int delaunay_reduce(double red_lattice[3][3], double const lattice[3][3],
+                           int const aperiodic_axis, double const symprec) {
     int succeeded, lattice_rank;
     int tmp_mat_int[3][3];
     double volume;
@@ -147,8 +147,7 @@ static int delaunay_reduce(double red_lattice[3][3], const double lattice[3][3],
 
     volume = mat_get_determinant_d3(red_lattice);
     if (mat_Dabs(volume) < symprec) {
-        warning_print("spglib: Minimum lattice has no volume (line %d, %s).\n",
-                      __LINE__, __FILE__);
+        info_print("spglib: Minimum lattice has no volume.\n");
         goto err;
     }
 
@@ -165,10 +164,9 @@ static int delaunay_reduce(double red_lattice[3][3], const double lattice[3][3],
     mat_multiply_matrix_d3(tmp_mat, tmp_mat, orig_lattice);
     mat_cast_matrix_3d_to_3i(tmp_mat_int, tmp_mat);
     if (abs(mat_get_determinant_i3(tmp_mat_int)) != 1) {
-        warning_print(
+        info_print(
             "spglib: Determinant of Delaunay change of basis matrix "
-            "has to be 1 or -1 (line %d, %s).\n",
-            __LINE__, __FILE__);
+            "has to be 1 or -1.\n");
         goto err;
     }
 
@@ -182,8 +180,8 @@ err:
 //        exists, find the shortest two vectors inside period plane and the
 //        shortest one outside.
 static void get_delaunay_shortest_vectors(double basis[4][3],
-                                          const int lattice_rank,
-                                          const double symprec) {
+                                          int const lattice_rank,
+                                          double const symprec) {
     int i, j;
     double tmpmat[3][3], b[7][3], tmpvec[3];
 
@@ -279,8 +277,8 @@ static void get_delaunay_shortest_vectors(double basis[4][3],
 
 // If `lattice_rank==2`, assume `basis[2]` (b3) is along aperiodic axis.
 // TODO: Change `lattice_rank` to a more informative variable
-static int delaunay_reduce_basis(double basis[4][3], const int lattice_rank,
-                                 const double symprec) {
+static int delaunay_reduce_basis(double basis[4][3], int const lattice_rank,
+                                 double const symprec) {
     int i, j, k, l;
     double dot_product;
 
@@ -311,10 +309,10 @@ static int delaunay_reduce_basis(double basis[4][3], const int lattice_rank,
                      * affect the final results */
                     /* except the primitive cell is not a standard Delaunay
                      * cell, so just a warning. */
-                    warning_print(
+                    info_print(
                         "spglib: Dot product between basis %d, %d larger than "
-                        "0 (line %d, %s).\n",
-                        i + 1, j + 1, __LINE__, __FILE__);
+                        "0.\n",
+                        i + 1, j + 1);
                     debug_print_vectors_d3(basis, 4);
                 }
             }
@@ -327,8 +325,8 @@ static int delaunay_reduce_basis(double basis[4][3], const int lattice_rank,
 // @brief Get extended basis for three-dimensional Delaunay reduction.
 //        If exists, `aperiodic_axis` is temporarily moved to b3 (`basis[2]`).
 // @return lattice_rank Rank of `lattice`
-static int get_extended_basis(double basis[4][3], const double lattice[3][3],
-                              const int aperiodic_axis) {
+static int get_extended_basis(double basis[4][3], double const lattice[3][3],
+                              int const aperiodic_axis) {
     int i, j, lattice_rank;
 
     if (aperiodic_axis == -1) {
@@ -362,10 +360,10 @@ static int get_extended_basis(double basis[4][3], const double lattice[3][3],
 }
 
 int del_layer_delaunay_reduce_2D(double red_lattice[3][3],
-                                 const double lattice[3][3],
-                                 const int unique_axis,
-                                 const int aperiodic_axis,
-                                 const double symprec) {
+                                 double const lattice[3][3],
+                                 int const unique_axis,
+                                 int const aperiodic_axis,
+                                 double const symprec) {
     int succeeded, lattice_rank;
     double volume;
     double basis[3][3], lattice_2D[3][2], unique_vec[3];
@@ -431,8 +429,7 @@ int del_layer_delaunay_reduce_2D(double red_lattice[3][3],
 
     volume = mat_get_determinant_d3(red_lattice);
     if (mat_Dabs(volume) < symprec) {
-        warning_print("spglib: Minimum lattice has no volume (line %d, %s).\n",
-                      __LINE__, __FILE__);
+        info_print("spglib: Minimum lattice has no volume.\n");
         goto err;
     }
 
@@ -448,8 +445,8 @@ err:
     return 0;
 }
 
-static int delaunay_reduce_basis_2D(double basis[3][3], const int lattice_rank,
-                                    const double symprec) {
+static int delaunay_reduce_basis_2D(double basis[3][3], int const lattice_rank,
+                                    double const symprec) {
     int i, j, k, l;
     double dot_product;
 
@@ -474,10 +471,10 @@ static int delaunay_reduce_basis_2D(double basis[3][3], const int lattice_rank,
                     }
                     return 0;
                 } else {
-                    warning_print(
+                    info_print(
                         "spglib: Dot product between basis %d, %d larger than "
-                        "0 (line %d, %s).\n",
-                        i + 1, j + 1, __LINE__, __FILE__);
+                        "0.\n",
+                        i + 1, j + 1);
                     debug_print_vectors_d3(basis, 3);
                 }
             }
@@ -488,9 +485,9 @@ static int delaunay_reduce_basis_2D(double basis[3][3], const int lattice_rank,
 }
 
 static void get_delaunay_shortest_vectors_2D(double basis[3][3],
-                                             const double unique_vec[3],
-                                             const int lattice_rank,
-                                             const double symprec) {
+                                             double const unique_vec[3],
+                                             int const lattice_rank,
+                                             double const symprec) {
     int i, j;
     double b[4][3], tmpmat[3][3];
     double tmpvec[3];
@@ -538,7 +535,7 @@ static void get_delaunay_shortest_vectors_2D(double basis[3][3],
 }
 
 static void get_extended_basis_2D(double basis[3][3],
-                                  const double lattice[3][2]) {
+                                  double const lattice[3][2]) {
     int i, j;
 
     for (i = 0; i < 2; i++) {
