@@ -48,14 +48,14 @@
 #define ANGLE_REDUCE_RATE 0.95
 #define NUM_ATTEMPT 20
 
-static DataContainer *get_spacegroup_and_primitive(const Cell *cell,
-                                                   const int hall_number,
-                                                   const double symprec,
-                                                   const double angle_symprec);
+static DataContainer *get_spacegroup_and_primitive(Cell const *cell,
+                                                   int const hall_number,
+                                                   double const symprec,
+                                                   double const angle_symprec);
 
-DataContainer *det_determine_all(const Cell *cell, const int hall_number,
-                                 const double symprec,
-                                 const double angle_symprec) {
+DataContainer *det_determine_all(Cell const *cell, int const hall_number,
+                                 double const symprec,
+                                 double const angle_symprec) {
     int attempt;
     double tolerance;
     DataContainer *container;
@@ -77,9 +77,8 @@ DataContainer *det_determine_all(const Cell *cell, const int hall_number,
                          container->primitive->tolerance)) != NULL) {
                 goto found;
             }
-            warning_print(
-                "spglib: ref_get_exact_structure_and_symmetry failed.");
-            warning_print(" (line %d, %s).\n", __LINE__, __FILE__);
+            debug_print(
+                "spglib: ref_get_exact_structure_and_symmetry failed.\n");
             det_free_container(container);
             container = NULL;
         }
@@ -109,10 +108,10 @@ void det_free_container(DataContainer *container) {
 }
 
 /* NULL is returned if failed */
-static DataContainer *get_spacegroup_and_primitive(const Cell *cell,
-                                                   const int hall_number,
-                                                   const double symprec,
-                                                   const double angle_symprec) {
+static DataContainer *get_spacegroup_and_primitive(Cell const *cell,
+                                                   int const hall_number,
+                                                   double const symprec,
+                                                   double const angle_symprec) {
     int attempt;
     double tolerance, angle_tolerance;
     DataContainer *container;
@@ -122,7 +121,7 @@ static DataContainer *get_spacegroup_and_primitive(const Cell *cell,
     container = NULL;
 
     if ((container = (DataContainer *)malloc(sizeof(DataContainer))) == NULL) {
-        warning_print("spglib: Memory could not be allocated.");
+        warning_memory("container");
         return NULL;
     }
 
@@ -136,7 +135,6 @@ static DataContainer *get_spacegroup_and_primitive(const Cell *cell,
     for (attempt = 0; attempt < NUM_ATTEMPT; attempt++) {
         if ((container->primitive =
                  prm_get_primitive(cell, tolerance, angle_tolerance)) != NULL) {
-            debug_print("[line %d, %s]\n", __LINE__, __FILE__);
             debug_print("primitive lattice\n");
             debug_print_matrix_d3(container->primitive->cell->lattice);
 
@@ -151,9 +149,8 @@ static DataContainer *get_spacegroup_and_primitive(const Cell *cell,
             container->primitive = NULL;
         }
 
-        warning_print("spglib: Attempt %d tolerance = %f failed.", attempt,
-                      tolerance);
-        warning_print(" (line %d, %s).\n", __LINE__, __FILE__);
+        debug_print("spglib: Attempt %d tolerance = %f failed.\n", attempt,
+                    tolerance);
 
         tolerance *= REDUCE_RATE;
         if (angle_tolerance > 0) {
