@@ -41,44 +41,44 @@
 
 int kpt_get_irreducible_reciprocal_mesh(int grid_address[][3],
                                         int ir_mapping_table[],
-                                        const int mesh[3],
-                                        const int is_shift[3],
-                                        const MatINT *rot_reciprocal);
+                                        int const mesh[3],
+                                        int const is_shift[3],
+                                        MatINT const *rot_reciprocal);
 size_t kpt_get_dense_irreducible_reciprocal_mesh(int grid_address[][3],
                                                  size_t ir_mapping_table[],
-                                                 const int mesh[3],
-                                                 const int is_shift[3],
-                                                 const MatINT *rot_reciprocal);
+                                                 int const mesh[3],
+                                                 int const is_shift[3],
+                                                 MatINT const *rot_reciprocal);
 int kpt_get_stabilized_reciprocal_mesh(
-    int grid_address[][3], int ir_mapping_table[], const int mesh[3],
-    const int is_shift[3], const int is_time_reversal, const MatINT *rotations,
-    const size_t num_q, const double qpoints[][3]);
+    int grid_address[][3], int ir_mapping_table[], int const mesh[3],
+    int const is_shift[3], int const is_time_reversal, MatINT const *rotations,
+    size_t const num_q, double const qpoints[][3]);
 size_t kpt_get_dense_stabilized_reciprocal_mesh(
-    int grid_address[][3], size_t ir_mapping_table[], const int mesh[3],
-    const int is_shift[3], const int is_time_reversal, const MatINT *rotations,
-    const size_t num_q, const double qpoints[][3]);
+    int grid_address[][3], size_t ir_mapping_table[], int const mesh[3],
+    int const is_shift[3], int const is_time_reversal, MatINT const *rotations,
+    size_t const num_q, double const qpoints[][3]);
 void kpt_get_dense_grid_points_by_rotations(size_t rot_grid_points[],
-                                            const int address_orig[3],
-                                            const int (*rot_reciprocal)[3][3],
-                                            const int num_rot,
-                                            const int mesh[3],
-                                            const int is_shift[3]);
+                                            int const address_orig[3],
+                                            int const (*rot_reciprocal)[3][3],
+                                            int const num_rot,
+                                            int const mesh[3],
+                                            int const is_shift[3]);
 void kpt_get_dense_BZ_grid_points_by_rotations(
-    size_t rot_grid_points[], const int address_orig[3],
-    const int (*rot_reciprocal)[3][3], const int num_rot, const int mesh[3],
-    const int is_shift[3], const size_t bz_map[]);
+    size_t rot_grid_points[], int const address_orig[3],
+    int const (*rot_reciprocal)[3][3], int const num_rot, int const mesh[3],
+    int const is_shift[3], size_t const bz_map[]);
 int kpt_relocate_BZ_grid_address(int bz_grid_address[][3], int bz_map[],
-                                 const int grid_address[][3], const int mesh[3],
-                                 const double rec_lattice[3][3],
-                                 const int is_shift[3]);
+                                 int const grid_address[][3], int const mesh[3],
+                                 double const rec_lattice[3][3],
+                                 int const is_shift[3]);
 size_t kpt_relocate_dense_BZ_grid_address(
-    int bz_grid_address[][3], size_t bz_map[], const int grid_address[][3],
-    const int mesh[3], const double rec_lattice[3][3], const int is_shift[3]);
-MatINT *kpt_get_point_group_reciprocal(const MatINT *rotations,
-                                       const int is_time_reversal);
-MatINT *kpt_get_point_group_reciprocal_with_q(const MatINT *rot_reciprocal,
-                                              const double symprec,
-                                              const size_t num_q,
-                                              const double qpoints[][3]);
+    int bz_grid_address[][3], size_t bz_map[], int const grid_address[][3],
+    int const mesh[3], double const rec_lattice[3][3], int const is_shift[3]);
+MatINT *kpt_get_point_group_reciprocal(MatINT const *rotations,
+                                       int const is_time_reversal);
+MatINT *kpt_get_point_group_reciprocal_with_q(MatINT const *rot_reciprocal,
+                                              double const symprec,
+                                              size_t const num_q,
+                                              double const qpoints[][3]);
 
 #endif
