@@ -52,13 +52,13 @@ typedef struct {
 } MagneticDataset;
 
 MagneticDataset *msg_identify_magnetic_space_group_type(
-    const double lattice[3][3], const MagneticSymmetry *magnetic_symmetry,
-    const double symprec);
-Cell *msg_get_transformed_cell(const Cell *cell, const double tmat[3][3],
-                               const double origin_shift[3],
-                               const double rigid_rot[3][3],
-                               const MagneticSymmetry *magnetic_symmetry,
-                               const double symprec,
-                               const double angle_tolerance);
+    double const lattice[3][3], MagneticSymmetry const *magnetic_symmetry,
+    double const symprec);
+Cell *msg_get_transformed_cell(Cell const *cell, double const tmat[3][3],
+                               double const origin_shift[3],
+                               double const rigid_rot[3][3],
+                               MagneticSymmetry const *magnetic_symmetry,
+                               double const symprec,
+                               double const angle_tolerance);
 
 #endif /*__msg_H__ */
