@@ -45,66 +45,66 @@
 /* 'a++' generalized to an arbitrary increment. */
 /* Performs 'a += b' and returns the old value of a. */
 #ifndef SPG_POST_INCREMENT
-#define SPG_POST_INCREMENT(a, b) ((a) += (b), (a) - (b))
+    #define SPG_POST_INCREMENT(a, b) ((a) += (b), (a) - (b))
 #endif
 
 /* deal with inline */
 #if defined(_MSC_VER)
-#define OVL_INLINE __forceinline
+    #define OVL_INLINE __forceinline
 #elif defined(__clang__)
-#define OVL_INLINE __inline__ __attribute__((__always_inline__))
+    #define OVL_INLINE __inline__ __attribute__((__always_inline__))
 #elif defined(__GNUC__) &&                                   \
     (defined(__GNUC_STDC_INLINE__) ||                        \
      (defined(__STDC__) && (__STDC_VERSION__ >= 199901L)) || \
      (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 2)))
-#define OVL_INLINE __inline__ __attribute__((__always_inline__))
+    #define OVL_INLINE __inline__ __attribute__((__always_inline__))
 #else
-#define OVL_INLINE /* empty */
+    #define OVL_INLINE /* empty */
 #endif
 
 /* Note: data_out and data_in MUST NOT ALIAS. */
-static void permute(void *data_out, const void *data_in, const int *perm,
+static void permute(void *data_out, void const *data_in, int const *perm,
                     int value_size, int n);
 
-static void permute_int(int *data_out, const int *data_in, const int *perm,
-                        const int n);
+static void permute_int(int *data_out, int const *data_in, int const *perm,
+                        int const n);
 
-static void permute_double_3(double (*data_out)[3], const double (*data_in)[3],
-                             const int *perm, const int n);
+static void permute_double_3(double (*data_out)[3], double const (*data_in)[3],
+                             int const *perm, int const n);
 
-static int ValueWithIndex_comparator(const void *pa, const void *pb);
+static int ValueWithIndex_comparator(void const *pa, void const *pb);
 
 static void *perm_argsort_work_malloc(int n);
 
 static void perm_argsort_work_free(void *work);
 
-static int perm_argsort(int *perm, const int *types, const double *values,
-                        void *provided_work, const int n);
+static int perm_argsort(int *perm, int const *types, double const *values,
+                        void *provided_work, int const n);
 
 static int check_possible_overlap(OverlapChecker *checker,
-                                  const double test_trans[3],
-                                  const int rot[3][3], const double symprec);
+                                  double const test_trans[3],
+                                  int const rot[3][3], double const symprec);
 
 static int argsort_by_lattice_point_distance(
-    int *perm, const double lattice[3][3], const double (*positions)[3],
-    const int *types, double *distance_temp, void *argsort_work,
-    const int size);
+    int *perm, double const lattice[3][3], double const (*positions)[3],
+    int const *types, double *distance_temp, void *argsort_work,
+    int const size);
 
 static OverlapChecker *overlap_checker_alloc(int size);
 
 static int check_total_overlap_for_sorted(
-    const double lattice[3][3], const double (*pos_original)[3],
-    const double (*pos_rotated)[3], const int types_original[],
-    const int types_rotated[], const int num_pos, const double symprec);
+    double const lattice[3][3], double const (*pos_original)[3],
+    double const (*pos_rotated)[3], int const types_original[],
+    int const types_rotated[], int const num_pos, double const symprec);
 /* ovl_check_total_overlap ,check_total_overlap_for_sorted, layer_has_overlap */
 /* and layer_has_overlap_with_same_type are copied to get rid of some if
  * statement */
 /* I have not tested if it is better in efficiency. */
 static int check_layer_total_overlap_for_sorted(
-    const double lattice[3][3], const double (*pos_original)[3],
-    const double (*pos_rotated)[3], const int types_original[],
-    const int types_rotated[], const int num_pos, const int periodic_axes[3],
-    const double symprec);
+    double const lattice[3][3], double const (*pos_original)[3],
+    double const (*pos_rotated)[3], int const types_original[],
+    int const types_rotated[], int const num_pos, int const periodic_axes[3],
+    double const symprec);
 
 /* Note that some compilers apparently don't like it
  * when you have a separate prototype with a function
@@ -113,8 +113,8 @@ static int check_layer_total_overlap_for_sorted(
  * As an aside, yes, significant performance is lost
  * for large structures if these functions aren't inlined. */
 
-static OVL_INLINE double cartesian_norm(const double lat[3][3],
-                                        const double v[3]) {
+static OVL_INLINE double cartesian_norm(double const lat[3][3],
+                                        double const v[3]) {
     double temp[3];
     temp[0] = lat[0][0] * v[0] + lat[0][1] * v[1] + lat[0][2] * v[2];
     temp[1] = lat[1][0] * v[0] + lat[1][1] * v[1] + lat[1][2] * v[2];
@@ -123,16 +123,16 @@ static OVL_INLINE double cartesian_norm(const double lat[3][3],
     return sqrt(temp[0] * temp[0] + temp[1] * temp[1] + temp[2] * temp[2]);
 }
 
-static OVL_INLINE int Nint(const double a) {
+static OVL_INLINE int Nint(double const a) {
     if (a < 0.0)
         return (int)(a - 0.5);
     else
         return (int)(a + 0.5);
 }
 
-static OVL_INLINE int has_overlap(const double a[3], const double b[3],
-                                  const double lattice[3][3],
-                                  const double symprec) {
+static OVL_INLINE int has_overlap(double const a[3], double const b[3],
+                                  double const lattice[3][3],
+                                  double const symprec) {
     double v_diff[3];
     v_diff[0] = a[0] - b[0];
     v_diff[2] = a[2] - b[2];
@@ -150,8 +150,8 @@ static OVL_INLINE int has_overlap(const double a[3], const double b[3],
 }
 
 static OVL_INLINE int has_overlap_with_same_type(
-    const double a[3], const double b[3], const int type_a, const int type_b,
-    const double lattice[3][3], const double symprec) {
+    double const a[3], double const b[3], int const type_a, int const type_b,
+    double const lattice[3][3], double const symprec) {
     if (type_a == type_b) {
         return has_overlap(a, b, lattice, symprec);
     } else {
@@ -160,10 +160,10 @@ static OVL_INLINE int has_overlap_with_same_type(
 }
 
 /* Modified from has_overlap */
-static OVL_INLINE int layer_has_overlap(const double a[3], const double b[3],
-                                        const double lattice[3][3],
-                                        const int periodic_axes[2],
-                                        const double symprec) {
+static OVL_INLINE int layer_has_overlap(double const a[3], double const b[3],
+                                        double const lattice[3][3],
+                                        int const periodic_axes[2],
+                                        double const symprec) {
     double v_diff[3];
     v_diff[0] = a[0] - b[0];
     v_diff[1] = a[1] - b[1];
@@ -180,9 +180,9 @@ static OVL_INLINE int layer_has_overlap(const double a[3], const double b[3],
 }
 
 static OVL_INLINE int layer_has_overlap_with_same_type(
-    const double a[3], const double b[3], const int type_a, const int type_b,
-    const double lattice[3][3], const int periodic_axes[2],
-    const double symprec) {
+    double const a[3], double const b[3], int const type_a, int const type_b,
+    double const lattice[3][3], int const periodic_axes[2],
+    double const symprec) {
     if (type_a == type_b) {
         return layer_has_overlap(a, b, lattice, periodic_axes, symprec);
     } else {
@@ -214,7 +214,7 @@ void ovl_overlap_checker_free(OverlapChecker *checker) {
     }
 }
 
-OverlapChecker *ovl_overlap_checker_init(const Cell *cell) {
+OverlapChecker *ovl_overlap_checker_init(Cell const *cell) {
     int i, lattice_rank;
     OverlapChecker *checker;
     checker = NULL;
@@ -260,9 +260,9 @@ OverlapChecker *ovl_overlap_checker_init(const Cell *cell) {
 /* you can create one OverlapChecker from the Cell and call this function many
  * times. */
 /* -1: Error.  0:  Not a symmetry.   1. Is a symmetry. */
-int ovl_check_total_overlap(OverlapChecker *checker, const double test_trans[3],
-                            const int rot[3][3], const double symprec,
-                            const int is_identity) {
+int ovl_check_total_overlap(OverlapChecker *checker, double const test_trans[3],
+                            int const rot[3][3], double const symprec,
+                            int const is_identity) {
     int i, k, check;
 
     /* Check a few atoms by brute force before continuing. */
@@ -322,9 +322,9 @@ int ovl_check_total_overlap(OverlapChecker *checker, const double test_trans[3],
  * times. */
 /* -1: Error.  0:  Not a symmetry.   1. Is a symmetry. */
 int ovl_check_layer_total_overlap(OverlapChecker *checker,
-                                  const double test_trans[3],
-                                  const int rot[3][3], const double symprec,
-                                  const int is_identity) {
+                                  double const test_trans[3],
+                                  int const rot[3][3], double const symprec,
+                                  int const is_identity) {
     int i, k, check;
 
     /* Check a few atoms by brute force before continuing. */
@@ -376,7 +376,7 @@ int ovl_check_layer_total_overlap(OverlapChecker *checker,
     return check;
 }
 
-static int ValueWithIndex_comparator(const void *pa, const void *pb) {
+static int ValueWithIndex_comparator(void const *pa, void const *pb) {
     int cmp;
     ValueWithIndex a, b;
 
@@ -399,8 +399,7 @@ static void *perm_argsort_work_malloc(int n) {
 
     if ((work = (ValueWithIndex *)(malloc(sizeof(ValueWithIndex) * n))) ==
         NULL) {
-        warning_print(
-            "spglib: Memory could not be allocated for argsort workspace.");
+        warning_memory("work");
         return NULL;
     }
     return work;
@@ -413,8 +412,8 @@ static void perm_argsort_work_free(void *work) { free(work); }
 /* to have the same type. */
 /* */
 /* Returns 0 on failure. */
-static int perm_argsort(int *perm, const int *types, const double *values,
-                        void *provided_work, const int n) {
+static int perm_argsort(int *perm, int const *types, double const *values,
+                        void *provided_work, int const n) {
     int i;
     ValueWithIndex *work;
 
@@ -451,10 +450,10 @@ static int perm_argsort(int *perm, const int *types, const double *values,
 
 /* Permute an array. */
 /* data_out and data_in MUST NOT ALIAS. */
-static void permute(void *data_out, const void *data_in, const int *perm,
+static void permute(void *data_out, void const *data_in, int const *perm,
                     int value_size, int n) {
     int i;
-    const void *read;
+    void const *read;
     void *write;
 
     for (i = 0; i < n; i++) {
@@ -467,13 +466,13 @@ static void permute(void *data_out, const void *data_in, const int *perm,
 /* ***************************************** */
 /*             OverlapChecker                */
 
-static void permute_int(int *data_out, const int *data_in, const int *perm,
-                        const int n) {
+static void permute_int(int *data_out, int const *data_in, int const *perm,
+                        int const n) {
     permute(data_out, data_in, perm, sizeof(int), n);
 }
 
-static void permute_double_3(double (*data_out)[3], const double (*data_in)[3],
-                             const int *perm, const int n) {
+static void permute_double_3(double (*data_out)[3], double const (*data_in)[3],
+                             int const *perm, int const n) {
     permute(data_out, data_in, perm, sizeof(double[3]), n);
 }
 
@@ -503,12 +502,12 @@ static OverlapChecker *overlap_checker_alloc(int size) {
     blob_size = offset;
 
     if ((checker = (OverlapChecker *)malloc(sizeof(OverlapChecker))) == NULL) {
-        warning_print("spglib: Memory could not be allocated for checker.");
+        warning_memory("checker");
         return NULL;
     }
 
     if ((checker->blob = malloc(blob_size)) == NULL) {
-        warning_print("spglib: Memory could not be allocated for checker.");
+        warning_memory("checker->blob");
         free(checker);
         checker = NULL;
         return NULL;
@@ -541,9 +540,9 @@ static OverlapChecker *overlap_checker_alloc(int size) {
 }
 
 static int argsort_by_lattice_point_distance(
-    int *perm, const double lattice[3][3], const double (*positions)[3],
-    const int *types, double *distance_temp, void *argsort_work,
-    const int size) {
+    int *perm, double const lattice[3][3], double const (*positions)[3],
+    int const *types, double *distance_temp, void *argsort_work,
+    int const size) {
     double diff[3];
     int i, k;
     double x;
@@ -569,8 +568,8 @@ static int argsort_by_lattice_point_distance(
 /* It only inspects a few atoms. */
 /* 0:  Not a symmetry.   1. Possible symmetry. */
 static int check_possible_overlap(OverlapChecker *checker,
-                                  const double test_trans[3],
-                                  const int rot[3][3], const double symprec) {
+                                  double const test_trans[3],
+                                  int const rot[3][3], double const symprec) {
     double pos_rot[3];
     int i, i_test, k, max_search_num, search_num;
     int type_rot, is_found;
@@ -617,9 +616,9 @@ static int check_possible_overlap(OverlapChecker *checker,
 /* between pos_original and pos_rotated is small. */
 /* -1: Error.  0: False.  1:  True. */
 static int check_total_overlap_for_sorted(
-    const double lattice[3][3], const double (*pos_original)[3],
-    const double (*pos_rotated)[3], const int types_original[],
-    const int types_rotated[], const int num_pos, const double symprec) {
+    double const lattice[3][3], double const (*pos_original)[3],
+    double const (*pos_rotated)[3], int const types_original[],
+    int const types_rotated[], int const num_pos, double const symprec) {
     int *found;
     int i, i_orig, i_rot;
     int search_start;
@@ -627,7 +626,7 @@ static int check_total_overlap_for_sorted(
     found = NULL;
 
     if ((found = (int *)malloc(num_pos * sizeof(int))) == NULL) {
-        warning_print("spglib: Memory could not be allocated");
+        warning_memory("found");
         return -1;
     }
 
@@ -679,10 +678,10 @@ static int check_total_overlap_for_sorted(
 /* between pos_original and pos_rotated is small. */
 /* -1: Error.  0: False.  1:  True. */
 static int check_layer_total_overlap_for_sorted(
-    const double lattice[3][3], const double (*pos_original)[3],
-    const double (*pos_rotated)[3], const int types_original[],
-    const int types_rotated[], const int num_pos, const int periodic_axes[3],
-    const double symprec) {
+    double const lattice[3][3], double const (*pos_original)[3],
+    double const (*pos_rotated)[3], int const types_original[],
+    int const types_rotated[], int const num_pos, int const periodic_axes[3],
+    double const symprec) {
     int *found;
     int i, i_orig, i_rot;
     int search_start;
@@ -690,7 +689,7 @@ static int check_layer_total_overlap_for_sorted(
     found = NULL;
 
     if ((found = (int *)malloc(num_pos * sizeof(int))) == NULL) {
-        warning_print("spglib: Memory could not be allocated");
+        warning_memory("found");
         return -1;
     }
 
