@@ -41,8 +41,8 @@
 
 VecDBL* ssm_get_exact_positions(int* wyckoffs, int* equiv_atoms,
                                 char (*site_symmetry_symbols)[7],
-                                const Cell* bravais, const Symmetry* conv_sym,
-                                const int num_pure_trans, const int hall_number,
-                                const double symprec);
+                                Cell const* bravais, Symmetry const* conv_sym,
+                                int const num_pure_trans, int const hall_number,
+                                double const symprec);
 
 #endif
