@@ -50,11 +50,11 @@ typedef struct {
     int pointgroup_number;
 } SpacegroupType;
 
-void spgdb_decode_symmetry(int rot[3][3], double trans[3], const int encoded);
-int spgdb_get_operation(int rot[3][3], double trans[3], const int hall_number);
-void spgdb_get_operation_index(int indices[2], const int hall_number);
-Symmetry* spgdb_get_spacegroup_operations(const int hall_number);
-SpacegroupType spgdb_get_spacegroup_type(const int hall_number);
-int spgdb_remove_space(char symbol[], const int num_char);
+void spgdb_decode_symmetry(int rot[3][3], double trans[3], int const encoded);
+int spgdb_get_operation(int rot[3][3], double trans[3], int const hall_number);
+void spgdb_get_operation_index(int indices[2], int const hall_number);
+Symmetry* spgdb_get_spacegroup_operations(int const hall_number);
+SpacegroupType spgdb_get_spacegroup_type(int const hall_number);
+int spgdb_remove_space(char symbol[], int const num_char);
 
 #endif
