@@ -62,61 +62,61 @@ static int relative_axes[][3] = {
 
 static int identity[3][3] = {{1, 0, 0}, {0, 1, 0}, {0, 0, 1}};
 
-static int get_index_with_least_atoms(const Cell *cell);
-static VecDBL *get_translation(const int rot[3][3], const Cell *cell,
-                               const double symprec, const int is_identity);
-static Symmetry *get_operations(const Cell *primitive, const double symprec,
-                                const double angle_symprec);
-static Symmetry *reduce_operation(const Cell *primitive,
-                                  const Symmetry *symmetry,
-                                  const double symprec,
-                                  const double angle_symprec,
-                                  const int is_pure_trans);
-static int search_translation_part(int atoms_found[], const Cell *cell,
-                                   const int rot[3][3],
-                                   const int min_atom_index,
-                                   const double origin[3], const double symprec,
-                                   const int is_identity);
-static int search_pure_translations(int atoms_found[], const Cell *cell,
-                                    const double trans[3],
-                                    const double symprec);
-static int is_overlap_all_atoms(const double test_trans[3], const int rot[3][3],
-                                const Cell *cell, const double symprec,
-                                const int is_identity);
+static int get_index_with_least_atoms(Cell const *cell);
+static VecDBL *get_translation(int const rot[3][3], Cell const *cell,
+                               double const symprec, int const is_identity);
+static Symmetry *get_operations(Cell const *primitive, double const symprec,
+                                double const angle_symprec);
+static Symmetry *reduce_operation(Cell const *primitive,
+                                  Symmetry const *symmetry,
+                                  double const symprec,
+                                  double const angle_symprec,
+                                  int const is_pure_trans);
+static int search_translation_part(int atoms_found[], Cell const *cell,
+                                   int const rot[3][3],
+                                   int const min_atom_index,
+                                   double const origin[3], double const symprec,
+                                   int const is_identity);
+static int search_pure_translations(int atoms_found[], Cell const *cell,
+                                    double const trans[3],
+                                    double const symprec);
+static int is_overlap_all_atoms(double const test_trans[3], int const rot[3][3],
+                                Cell const *cell, double const symprec,
+                                int const is_identity);
 static PointSymmetry transform_pointsymmetry(
-    const PointSymmetry *point_sym_prim, const double new_lattice[3][3],
-    const double original_lattice[3][3]);
-static Symmetry *get_space_group_operations(const PointSymmetry *lattice_sym,
-                                            const Cell *primitive,
-                                            const double symprec);
-static void set_axes(int axes[3][3], const int a1, const int a2, const int a3);
-static PointSymmetry get_lattice_symmetry(const Cell *cell,
-                                          const double symprec,
-                                          const double angle_symprec);
-static int is_identity_metric(const double metric_rotated[3][3],
-                              const double metric_orig[3][3],
-                              const double symprec, const double angle_symprec);
-static double get_angle(const double metric[3][3], const int i, const int j);
+    PointSymmetry const *point_sym_prim, double const new_lattice[3][3],
+    double const original_lattice[3][3]);
+static Symmetry *get_space_group_operations(PointSymmetry const *lattice_sym,
+                                            Cell const *primitive,
+                                            double const symprec);
+static void set_axes(int axes[3][3], int const a1, int const a2, int const a3);
+static PointSymmetry get_lattice_symmetry(Cell const *cell,
+                                          double const symprec,
+                                          double const angle_symprec);
+static int is_identity_metric(double const metric_rotated[3][3],
+                              double const metric_orig[3][3],
+                              double const symprec, double const angle_symprec);
+static double get_angle(double const metric[3][3], int const i, int const j);
 
 /* get_translation, search_translation_part and search_pure_translations */
 /* are duplicated to get the if statement outside the nested loops */
 /* I have not tested if it is better in efficiency. */
-static VecDBL *get_layer_translation(const int rot[3][3], const Cell *cell,
-                                     const double symprec,
-                                     const int is_identity);
-static int search_layer_translation_part(int atoms_found[], const Cell *cell,
-                                         const int rot[3][3],
-                                         const int min_atom_index,
-                                         const double origin[3],
-                                         const double symprec,
-                                         const int is_identity);
-static int search_layer_pure_translations(int atoms_found[], const Cell *cell,
-                                          const double trans[3],
-                                          const int periodic_axes[2],
-                                          const double symprec);
+static VecDBL *get_layer_translation(int const rot[3][3], Cell const *cell,
+                                     double const symprec,
+                                     int const is_identity);
+static int search_layer_translation_part(int atoms_found[], Cell const *cell,
+                                         int const rot[3][3],
+                                         int const min_atom_index,
+                                         double const origin[3],
+                                         double const symprec,
+                                         int const is_identity);
+static int search_layer_pure_translations(int atoms_found[], Cell const *cell,
+                                          double const trans[3],
+                                          int const periodic_axes[2],
+                                          double const symprec);
 
 /* Return NULL if failed */
-Symmetry *sym_alloc_symmetry(const int size) {
+Symmetry *sym_alloc_symmetry(int const size) {
     Symmetry *symmetry;
 
     symmetry = NULL;
@@ -126,7 +126,7 @@ Symmetry *sym_alloc_symmetry(const int size) {
     }
 
     if ((symmetry = (Symmetry *)malloc(sizeof(Symmetry))) == NULL) {
-        warning_print("spglib: Memory could not be allocated ");
+        warning_memory("symmetry");
         return NULL;
     }
 
@@ -136,16 +136,14 @@ Symmetry *sym_alloc_symmetry(const int size) {
 
     if ((symmetry->rot = (int(*)[3][3])malloc(sizeof(int[3][3]) * size)) ==
         NULL) {
-        warning_print("spglib: Memory could not be allocated ");
-        warning_print("(line %d, %s).\n", __LINE__, __FILE__);
+        warning_memory("symmetry->rot");
         free(symmetry);
         symmetry = NULL;
         return NULL;
     }
     if ((symmetry->trans = (double(*)[3])malloc(sizeof(double[3]) * size)) ==
         NULL) {
-        warning_print("spglib: Memory could not be allocated ");
-        warning_print("(line %d, %s).\n", __LINE__, __FILE__);
+        warning_memory("symmetry->trans");
         free(symmetry->rot);
         symmetry->rot = NULL;
         free(symmetry);
@@ -167,7 +165,7 @@ void sym_free_symmetry(Symmetry *symmetry) {
 }
 
 /* Return NULL if failed */
-MagneticSymmetry *sym_alloc_magnetic_symmetry(const int size) {
+MagneticSymmetry *sym_alloc_magnetic_symmetry(int const size) {
     MagneticSymmetry *symmetry;
 
     symmetry = NULL;
@@ -178,7 +176,7 @@ MagneticSymmetry *sym_alloc_magnetic_symmetry(const int size) {
 
     if ((symmetry = (MagneticSymmetry *)malloc(sizeof(MagneticSymmetry))) ==
         NULL) {
-        warning_print("spglib: Memory could not be allocated ");
+        warning_memory("symmetry");
         return NULL;
     }
 
@@ -189,16 +187,14 @@ MagneticSymmetry *sym_alloc_magnetic_symmetry(const int size) {
 
     if ((symmetry->rot = (int(*)[3][3])malloc(sizeof(int[3][3]) * size)) ==
         NULL) {
-        warning_print("spglib: Memory could not be allocated ");
-        warning_print("(line %d, %s).\n", __LINE__, __FILE__);
+        warning_memory("symmetry->rot");
         free(symmetry);
         symmetry = NULL;
         return NULL;
     }
     if ((symmetry->trans = (double(*)[3])malloc(sizeof(double[3]) * size)) ==
         NULL) {
-        warning_print("spglib: Memory could not be allocated ");
-        warning_print("(line %d, %s).\n", __LINE__, __FILE__);
+        warning_memory("symmetry->trans");
         free(symmetry->rot);
         symmetry->rot = NULL;
         free(symmetry);
@@ -206,8 +202,7 @@ MagneticSymmetry *sym_alloc_magnetic_symmetry(const int size) {
         return NULL;
     }
     if ((symmetry->timerev = (int *)malloc(sizeof(int *) * size)) == NULL) {
-        warning_print("spglib: Memory could not be allocated ");
-        warning_print("(line %d, %s).\n", __LINE__, __FILE__);
+        warning_memory("symmetry->timerev");
         free(symmetry->rot);
         symmetry->rot = NULL;
         free(symmetry->trans);
@@ -232,22 +227,22 @@ void sym_free_magnetic_symmetry(MagneticSymmetry *symmetry) {
 }
 
 /* Return NULL if failed */
-Symmetry *sym_get_operation(const Cell *primitive, const double symprec,
-                            const double angle_tolerance) {
+Symmetry *sym_get_operation(Cell const *primitive, double const symprec,
+                            double const angle_tolerance) {
     debug_print("sym_get_operations:\n");
 
     return get_operations(primitive, symprec, angle_tolerance);
 }
 
 /* Return NULL if failed */
-Symmetry *sym_reduce_operation(const Cell *primitive, const Symmetry *symmetry,
-                               const double symprec,
-                               const double angle_tolerance) {
+Symmetry *sym_reduce_operation(Cell const *primitive, Symmetry const *symmetry,
+                               double const symprec,
+                               double const angle_tolerance) {
     return reduce_operation(primitive, symmetry, symprec, angle_tolerance, 0);
 }
 
 /* Return NULL if failed */
-VecDBL *sym_get_pure_translation(const Cell *cell, const double symprec) {
+VecDBL *sym_get_pure_translation(Cell const *cell, double const symprec) {
     int multi;
     VecDBL *pure_trans;
 
@@ -261,20 +256,16 @@ VecDBL *sym_get_pure_translation(const Cell *cell, const double symprec) {
         pure_trans = get_layer_translation(identity, cell, symprec, 1);
     }
     if (pure_trans == NULL) {
-        warning_print("spglib: get_translation failed (line %d, %s).\n",
-                      __LINE__, __FILE__);
+        debug_print("spglib: get_translation failed.\n");
         return NULL;
     }
 
     multi = pure_trans->size;
     if ((cell->size / multi) * multi == cell->size) {
-        debug_print("  sym_get_pure_translation: pure_trans->size = %d\n",
+        debug_print("spglib: sym_get_pure_translation: pure_trans->size = %d\n",
                     multi);
     } else {
-        ;
-        warning_print(
-            "spglib: Finding pure translation failed (line %d, %s).\n",
-            __LINE__, __FILE__);
+        warning_print("spglib: Finding pure translation failed.\n");
         warning_print("        cell->size %d, multi %d\n", cell->size, multi);
     }
 
@@ -282,9 +273,9 @@ VecDBL *sym_get_pure_translation(const Cell *cell, const double symprec) {
 }
 
 /* Return NULL if failed */
-VecDBL *sym_reduce_pure_translation(const Cell *cell, const VecDBL *pure_trans,
-                                    const double symprec,
-                                    const double angle_tolerance) {
+VecDBL *sym_reduce_pure_translation(Cell const *cell, VecDBL const *pure_trans,
+                                    double const symprec,
+                                    double const angle_tolerance) {
     int i, multi;
     Symmetry *symmetry, *symmetry_reduced;
     VecDBL *pure_trans_reduced;
@@ -342,8 +333,8 @@ VecDBL *sym_reduce_pure_translation(const Cell *cell, const VecDBL *pure_trans,
 /* 3) The spacegroup operations for the primitive cell are */
 /*    transformed to those of original input cells, if the input cell */
 /*    was not a primitive cell. */
-static Symmetry *get_operations(const Cell *primitive, const double symprec,
-                                const double angle_symprec) {
+static Symmetry *get_operations(Cell const *primitive, double const symprec,
+                                double const angle_symprec) {
     PointSymmetry lattice_sym;
     Symmetry *symmetry;
 
@@ -365,11 +356,11 @@ static Symmetry *get_operations(const Cell *primitive, const double symprec,
 }
 
 /* Return NULL if failed */
-static Symmetry *reduce_operation(const Cell *primitive,
-                                  const Symmetry *symmetry,
-                                  const double symprec,
-                                  const double angle_symprec,
-                                  const int is_pure_trans) {
+static Symmetry *reduce_operation(Cell const *primitive,
+                                  Symmetry const *symmetry,
+                                  double const symprec,
+                                  double const angle_symprec,
+                                  int const is_pure_trans) {
     int i, j, num_sym;
     Symmetry *sym_reduced;
     PointSymmetry point_symmetry;
@@ -436,8 +427,8 @@ static Symmetry *reduce_operation(const Cell *primitive,
 /* Look for the translations which satisfy the input symmetry operation. */
 /* This function is heaviest in this code. */
 /* Return NULL if failed */
-static VecDBL *get_translation(const int rot[3][3], const Cell *cell,
-                               const double symprec, const int is_identity) {
+static VecDBL *get_translation(int const rot[3][3], Cell const *cell,
+                               double const symprec, int const is_identity) {
     int i, j, k, min_atom_index, num_trans;
     int *is_found;
     double origin[3];
@@ -450,7 +441,7 @@ static VecDBL *get_translation(const int rot[3][3], const Cell *cell,
     trans = NULL;
 
     if ((is_found = (int *)malloc(sizeof(int) * cell->size)) == NULL) {
-        warning_print("spglib: Memory could not be allocated ");
+        warning_memory("is_found");
         return NULL;
     }
 
@@ -498,11 +489,11 @@ ret:
 }
 
 /* Returns -1 on failure. */
-static int search_translation_part(int atoms_found[], const Cell *cell,
-                                   const int rot[3][3],
-                                   const int min_atom_index,
-                                   const double origin[3], const double symprec,
-                                   const int is_identity) {
+static int search_translation_part(int atoms_found[], Cell const *cell,
+                                   int const rot[3][3],
+                                   int const min_atom_index,
+                                   double const origin[3], double const symprec,
+                                   int const is_identity) {
     int i, j, num_trans, is_overlap;
     double trans[3];
     OverlapChecker *checker;
@@ -552,9 +543,9 @@ err:
     return -1;
 }
 
-static int search_pure_translations(int atoms_found[], const Cell *cell,
-                                    const double trans[3],
-                                    const double symprec) {
+static int search_pure_translations(int atoms_found[], Cell const *cell,
+                                    double const trans[3],
+                                    double const symprec) {
     int i, j, num_trans, i_atom, initial_atom;
     int *copy_atoms_found;
     double vec[3];
@@ -606,9 +597,9 @@ static int search_pure_translations(int atoms_found[], const Cell *cell,
 /* Thoroughly confirms that a given symmetry operation is a symmetry. */
 /* This is a convenient wrapper around ovl_check_total_overlap. */
 /* -1: Error.  0: Not a symmetry.  1: Is a symmetry. */
-static int is_overlap_all_atoms(const double trans[3], const int rot[3][3],
-                                const Cell *cell, const double symprec,
-                                const int is_identity) {
+static int is_overlap_all_atoms(double const trans[3], int const rot[3][3],
+                                Cell const *cell, double const symprec,
+                                int const is_identity) {
     OverlapChecker *checker;
     int result;
 
@@ -632,14 +623,14 @@ static int is_overlap_all_atoms(const double trans[3], const int rot[3][3],
     return result;
 }
 
-static int get_index_with_least_atoms(const Cell *cell) {
+static int get_index_with_least_atoms(Cell const *cell) {
     int i, j, min, min_index;
     int *mapping;
 
     mapping = NULL;
 
     if ((mapping = (int *)malloc(sizeof(int) * cell->size)) == NULL) {
-        warning_print("spglib: Memory could not be allocated ");
+        warning_memory("mapping");
         return -1;
     }
 
@@ -674,9 +665,9 @@ static int get_index_with_least_atoms(const Cell *cell) {
 /* Look for the translations which satisfy the input symmetry operation. */
 /* This function is heaviest in this code. */
 /* Return NULL if failed */
-static VecDBL *get_layer_translation(const int rot[3][3], const Cell *cell,
-                                     const double symprec,
-                                     const int is_identity) {
+static VecDBL *get_layer_translation(int const rot[3][3], Cell const *cell,
+                                     double const symprec,
+                                     int const is_identity) {
     int i, j, k, min_atom_index, num_trans;
     int *is_found;
     double origin[3];
@@ -689,7 +680,7 @@ static VecDBL *get_layer_translation(const int rot[3][3], const Cell *cell,
     trans = NULL;
 
     if ((is_found = (int *)malloc(sizeof(int) * cell->size)) == NULL) {
-        warning_print("spglib: Memory could not be allocated ");
+        warning_memory("is_found");
         return NULL;
     }
 
@@ -739,12 +730,12 @@ ret:
 }
 
 /* Returns -1 on failure. */
-static int search_layer_translation_part(int atoms_found[], const Cell *cell,
-                                         const int rot[3][3],
-                                         const int min_atom_index,
-                                         const double origin[3],
-                                         const double symprec,
-                                         const int is_identity) {
+static int search_layer_translation_part(int atoms_found[], Cell const *cell,
+                                         int const rot[3][3],
+                                         int const min_atom_index,
+                                         double const origin[3],
+                                         double const symprec,
+                                         int const is_identity) {
     int i, j, num_trans, is_overlap;
     double trans[3];
     OverlapChecker *checker;
@@ -794,10 +785,10 @@ err:
     return -1;
 }
 
-static int search_layer_pure_translations(int atoms_found[], const Cell *cell,
-                                          const double trans[3],
-                                          const int periodic_axes[2],
-                                          const double symprec) {
+static int search_layer_pure_translations(int atoms_found[], Cell const *cell,
+                                          double const trans[3],
+                                          int const periodic_axes[2],
+                                          double const symprec) {
     int i, j, num_trans, i_atom, initial_atom;
     int *copy_atoms_found;
     double vec[3];
@@ -848,9 +839,9 @@ static int search_layer_pure_translations(int atoms_found[], const Cell *cell,
 }
 
 /* Return NULL if failed */
-static Symmetry *get_space_group_operations(const PointSymmetry *lattice_sym,
-                                            const Cell *primitive,
-                                            const double symprec) {
+static Symmetry *get_space_group_operations(PointSymmetry const *lattice_sym,
+                                            Cell const *primitive,
+                                            double const symprec) {
     int i, j, num_sym, total_num_sym;
     VecDBL **trans;
     Symmetry *symmetry;
@@ -862,7 +853,7 @@ static Symmetry *get_space_group_operations(const PointSymmetry *lattice_sym,
 
     if ((trans = (VecDBL **)malloc(sizeof(VecDBL *) * lattice_sym->size)) ==
         NULL) {
-        warning_print("spglib: Memory could not be allocated ");
+        warning_memory("trans");
         return NULL;
     }
 
@@ -924,9 +915,9 @@ ret:
 }
 
 /* lattice_sym.size = 0 is returned if failed. */
-static PointSymmetry get_lattice_symmetry(const Cell *cell,
-                                          const double symprec,
-                                          const double angle_symprec) {
+static PointSymmetry get_lattice_symmetry(Cell const *cell,
+                                          double const symprec,
+                                          double const angle_symprec) {
     int i, j, k, attempt, num_sym, aperiodic_axis;
     double angle_tol;
     int axes[3][3];
@@ -1003,17 +994,15 @@ static PointSymmetry get_lattice_symmetry(const Cell *cell,
                                            angle_tol)) {
                         if ((aperiodic_axis == -1 && num_sym >= 48) ||
                             (aperiodic_axis != -1 && num_sym >= 24)) {
-                            warning_print(
-                                "spglib: Too many lattice symmetries was "
+                            debug_print(
+                                "spglib: Too many lattice symmetries were "
                                 "found.\n");
                             if (angle_tol > 0) {
                                 angle_tol *= ANGLE_REDUCE_RATE;
-                                warning_print(
-                                    "        Reduce angle tolerance to %f\n",
+                                debug_print(
+                                    "        Reducing angle tolerance to %f\n",
                                     angle_tol);
                             }
-                            warning_print("        (line %d, %s).\n", __LINE__,
-                                          __FILE__);
                             goto next_attempt;
                         }
 
@@ -1039,10 +1028,10 @@ err:
     return lattice_sym;
 }
 
-static int is_identity_metric(const double metric_rotated[3][3],
-                              const double metric_orig[3][3],
-                              const double symprec,
-                              const double angle_symprec) {
+static int is_identity_metric(double const metric_rotated[3][3],
+                              double const metric_orig[3][3],
+                              double const symprec,
+                              double const angle_symprec) {
     int i, j, k;
     int elem_sets[3][2] = {{0, 1}, {0, 2}, {1, 2}};
     double cos1, cos2, x, length_ave2, sin_dtheta2;
@@ -1090,7 +1079,7 @@ fail:
     return 0;
 }
 
-static double get_angle(const double metric[3][3], const int i, const int j) {
+static double get_angle(double const metric[3][3], int const i, int const j) {
     double length_i, length_j;
 
     length_i = sqrt(metric[i][i]);
@@ -1100,8 +1089,8 @@ static double get_angle(const double metric[3][3], const int i, const int j) {
 }
 
 static PointSymmetry transform_pointsymmetry(
-    const PointSymmetry *lat_sym_orig, const double new_lattice[3][3],
-    const double original_lattice[3][3]) {
+    PointSymmetry const *lat_sym_orig, double const new_lattice[3][3],
+    double const original_lattice[3][3]) {
     int i, size;
     double trans_mat[3][3], inv_mat[3][3], drot[3][3];
     PointSymmetry lat_sym_new;
@@ -1123,8 +1112,7 @@ static PointSymmetry transform_pointsymmetry(
             mat_cast_matrix_3d_to_3i(lat_sym_new.rot[size], drot);
             if (abs(mat_get_determinant_i3(lat_sym_new.rot[size])) != 1) {
                 warning_print(
-                    "spglib: A point symmetry operation is not unimodular.");
-                warning_print("(line %d, %s).\n", __LINE__, __FILE__);
+                    "spglib: A point symmetry operation is not unimodular.\n");
                 goto err;
             }
             size++;
@@ -1133,8 +1121,7 @@ static PointSymmetry transform_pointsymmetry(
 
     if (!(lat_sym_orig->size == size)) {
         warning_print(
-            "spglib: Some of point symmetry operations were dropped.");
-        warning_print("(line %d, %s).\n", __LINE__, __FILE__);
+            "spglib: Some of point symmetry operations were dropped.\n");
     }
 
     lat_sym_new.size = size;
@@ -1146,7 +1133,7 @@ err:
 
 // @brief Set an integer matrix to `axes`. Three integer vectors are specified
 //        by indices of array `symmetry.c:relative_axes`.
-static void set_axes(int axes[3][3], const int a1, const int a2, const int a3) {
+static void set_axes(int axes[3][3], int const a1, int const a2, int const a3) {
     int i;
     for (i = 0; i < 3; i++) {
         axes[i][0] = relative_axes[a1][i];
